from django.db import models
from django.utils.translation import ugettext_lazy as _

from .exercise_type import ExerciseType


class Evaluation(models.Model):
    evaluation_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=100, help_text='The name should be in English here')
    exercise_type = models.ForeignKey(ExerciseType, on_delete=models.CASCADE, verbose_name=_("exercise_type"),
                                      limit_choices_to={'active': True})
    unit = models.CharField(max_length=50, verbose_name=_("unit"))

    class Meta:
        db_table = 'evaluation'
        verbose_name = _("Evaluation")
        verbose_name_plural = _("Evaluations")

    def __str__(self):
        return self.name


class EvaluationAttribute(models.Model):
    class SexTypes(models.TextChoices):
        MAN = 'm'
        WOMAN = 'w'

    class EvaluationTypes(models.TextChoices):
        ELITE = "elite"
        EXCELLENT = "excellent"
        GOOD = "good"
        ABOVE_AVERAGE = "above_average"
        AVERAGE = "average"
        BELOW_AVERAGE = "below_average"
        FAIR = "fair"
        POOR = "poor"
        VERY_POOR = "very_poor"

    evaluation_attr_id = models.AutoField(primary_key=True)
    evaluation = models.ForeignKey(Evaluation, on_delete=models.CASCADE, verbose_name=_("evaluation_foreign"))
    name = models.CharField(max_length=100, help_text='The name should be in English here', verbose_name=_("name"))
    sex = models.CharField(max_length=1, choices=SexTypes.choices, default=SexTypes.MAN, verbose_name=_("sex"))
    age_min = models.IntegerField(verbose_name=_("age_min"))
    age_max = models.IntegerField(verbose_name=_("age_max"))
    value_min = models.FloatField(verbose_name=_("value_min"))
    value_max = models.FloatField(verbose_name=_("value_max"))
    evaluation_text = models.CharField(max_length=50, choices=EvaluationTypes.choices, default=EvaluationTypes.AVERAGE,
                                       verbose_name=_("evaluation_text"))
    suggestion = models.TextField(max_length=1000, blank=True, null=True, help_text="English suggestion here",
                                  verbose_name=_("suggestion"))
    sort = models.IntegerField()

    class Meta:
        db_table = 'evaluation_attribute'
        verbose_name = _("Evaluation Table")
        verbose_name_plural = _("Evaluation Tables")
        ordering = ['sort']

    def __str__(self):
        return self.name