from django.db import models
from django.utils.translation import ugettext_lazy as _

from .enums import LanguageTypes


class Property(models.Model):
    property_id = models.AutoField(primary_key=True)
    property_name = models.CharField(max_length=100, help_text='The name should be in English here')
    property_unit = models.CharField(max_length=10)

    class Meta:
        db_table = 'property'
        verbose_name = _("Customer Property")
        verbose_name_plural = _("Customer Properties")

    def __str__(self):
        return self.property_name


class PropertyTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    property = models.ForeignKey(Property, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    property_name = models.CharField(max_length=100)

    class Meta:
        db_table = 'property_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.property_name